-- =============================================
-- SaveToDB Framework for Microsoft SQL Server
-- Version 7.19, March 12, 2018
--
-- This script copies settings from SaveToDB Framework 5-7 to SaveToDB Framework 8.
-- SaveToDB Framework 8 must be installed.
-- You may remove SaveToDB Framework 5-7 manually after successful copying.
--
-- Copyright 2018 Gartle Technology Corporation
-- =============================================

SET NOCOUNT ON

PRINT 'Copying table data:';

PRINT 'savetodb_dev.query_list         -> xls.objects';

INSERT INTO xls.objects
    ( TABLE_SCHEMA
    , TABLE_NAME
    , TABLE_TYPE
    , TABLE_CODE
    , INSERT_OBJECT
    , UPDATE_OBJECT
    , DELETE_OBJECT
    )
SELECT
    s.TABLE_SCHEMA
    , s.TABLE_NAME
    , s.TABLE_TYPE
    , s.TABLE_CODE
    , s.INSERT_PROCEDURE
    , s.UPDATE_PROCEDURE
    , s.DELETE_PROCEDURE
FROM
    savetodb_dev.query_list s
    LEFT OUTER JOIN xls.objects t ON t.TABLE_SCHEMA = s.TABLE_SCHEMA AND t.TABLE_NAME = s.TABLE_NAME
WHERE
    NOT s.TABLE_SCHEMA IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;
GO

PRINT 'savetodb_dev.event_handlers     -> xls.handlers';

INSERT INTO xls.handlers
    ( TABLE_SCHEMA
    , TABLE_NAME
    , COLUMN_NAME
    , EVENT_NAME
    , HANDLER_SCHEMA
    , HANDLER_NAME
    , HANDLER_TYPE
    , HANDLER_CODE
    , TARGET_WORKSHEET
    , MENU_ORDER
    , EDIT_PARAMETERS
    )
SELECT
    s.TABLE_SCHEMA
    , s.TABLE_NAME
    , s.COLUMN_NAME
    , s.EVENT_NAME
    , s.HANDLER_SCHEMA
    , s.HANDLER_NAME
    , s.HANDLER_TYPE
    , s.HANDLER_CODE
    , s.TARGET_WORKSHEET
    , s.MENU_ORDER
    , s.EDIT_PARAMETERS
FROM
    savetodb_dev.event_handlers s
    LEFT OUTER JOIN xls.handlers t ON t.TABLE_SCHEMA = s.TABLE_SCHEMA AND t.TABLE_NAME = s.TABLE_NAME
        AND COALESCE(t.COLUMN_NAME, '')     = COALESCE(s.COLUMN_NAME, '')
        AND COALESCE(t.HANDLER_SCHEMA, '')  = COALESCE(s.HANDLER_SCHEMA, '')
        AND COALESCE(t.HANDLER_NAME, '')    = COALESCE(s.HANDLER_NAME, '')
        AND COALESCE(t.HANDLER_TYPE, '')    = COALESCE(s.HANDLER_TYPE, '')
        AND COALESCE(t.MENU_ORDER, 0)       = COALESCE(s.MENU_ORDER, 0)
WHERE
    NOT s.TABLE_SCHEMA IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;
GO

PRINT 'savetodb_dev.parameter_values   -> xls.handlers';

INSERT INTO xls.handlers
    ( TABLE_SCHEMA
    , TABLE_NAME
    , COLUMN_NAME
    , EVENT_NAME
    , HANDLER_SCHEMA
    , HANDLER_NAME
    , HANDLER_TYPE
    , HANDLER_CODE
    , TARGET_WORKSHEET
    , MENU_ORDER
    , EDIT_PARAMETERS
    )
SELECT
    s.TABLE_SCHEMA
    , s.TABLE_NAME
    , s.PARAMETER_NAME  AS COLUMN_NAME
    , 'ParameterValues' AS EVENT_NAME
    , s.SELECT_SCHEMA   AS HANDLER_SCHEMA
    , s.SELECT_NAME     AS HANDLER_NAME
    , s.SELECT_TYPE     AS HANDLER_TYPE
    , s.SELECT_CODE     AS HANDLER_CODE
    , NULL              AS TARGET_WORKSHEET
    , NULL              AS MENU_ORDER
    , NULL              AS EDIT_PARAMETERS
FROM
    savetodb_dev.parameter_values s
    LEFT OUTER JOIN xls.handlers t ON t.TABLE_SCHEMA = s.TABLE_SCHEMA AND t.TABLE_NAME = s.TABLE_NAME
        AND COALESCE(s.PARAMETER_NAME, '')  = COALESCE(t.COLUMN_NAME, '')
        AND COALESCE(s.SELECT_SCHEMA, '')   = COALESCE(t.HANDLER_SCHEMA, '')
        AND COALESCE(s.SELECT_NAME, '')     = COALESCE(t.HANDLER_NAME, '')
        AND COALESCE(s.SELECT_TYPE, '')     = COALESCE(t.HANDLER_TYPE, '')
WHERE
    NOT s.TABLE_SCHEMA IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;
GO

PRINT 'savetodb_dev.object_translation -> xls.translations';

INSERT INTO xls.translations
    ( TABLE_SCHEMA
    , TABLE_NAME
    , COLUMN_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    , TRANSLATED_COMMENT
    )
SELECT
    s.TABLE_SCHEMA
    , s.TABLE_NAME
    , NULL AS COLUMN_NAME
    , s.LANGUAGE_NAME
    , s.TRANSLATED_NAME
    , s.TRANSLATED_DESC
    , s.TRANSLATED_COMMENT
FROM
    savetodb_dev.object_translation s
    LEFT OUTER JOIN xls.translations t ON t.TABLE_SCHEMA = s.TABLE_SCHEMA AND t.TABLE_NAME = s.TABLE_NAME
        AND t.LANGUAGE_NAME = s.LANGUAGE_NAME AND t.COLUMN_NAME IS NULL
WHERE
    NOT s.TABLE_SCHEMA IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;
GO

PRINT 'savetodb_dev.column_translation -> xls.translations';

INSERT INTO xls.translations
    ( TABLE_SCHEMA
    , TABLE_NAME
    , COLUMN_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    , TRANSLATED_COMMENT
    )
SELECT
    s.TABLE_SCHEMA
    , s.TABLE_NAME
    , s.COLUMN_NAME
    , s.LANGUAGE_NAME
    , s.TRANSLATED_NAME
    , s.TRANSLATED_DESC
    , NULL AS TRANSLATED_COMMENT
FROM
    savetodb_dev.column_translation s
    LEFT OUTER JOIN xls.translations t ON t.TABLE_SCHEMA = s.TABLE_SCHEMA AND t.TABLE_NAME = s.TABLE_NAME
        AND t.LANGUAGE_NAME = s.LANGUAGE_NAME AND t.COLUMN_NAME = s.COLUMN_NAME
WHERE
    NOT s.TABLE_SCHEMA IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;
GO

PRINT 'savetodb_dev.table_formats      -> xls.formats';

INSERT INTO xls.formats
    ( TABLE_SCHEMA
    , TABLE_NAME
    , TABLE_EXCEL_FORMAT_XML
    )
SELECT
    s.TABLE_SCHEMA
    , s.TABLE_NAME
    , s.TABLE_EXCEL_FORMAT_XML
FROM
    savetodb_dev.table_formats s
    LEFT OUTER JOIN xls.formats t ON t.TABLE_SCHEMA = s.TABLE_SCHEMA AND t.TABLE_NAME = s.TABLE_NAME
WHERE
    NOT s.TABLE_SCHEMA IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;
GO

DECLARE @sql nvarchar(max)

SELECT @sql = ( 
    SELECT
        'ALTER ROLE ' + CASE p.name WHEN 'savetodb_dev_role' THEN 'xls_developers' ELSE 'xls_users' END + ' ADD MEMBER ' + QUOTENAME(m.name) + ';' + CHAR(10)
    FROM
        sys.database_role_members rm
        INNER JOIN sys.database_principals p ON p.principal_id = rm.role_principal_id
        INNER JOIN sys.database_principals m ON m.principal_id = rm.member_principal_id
    WHERE
        p.name IN ('savetodb_dev_role', 'savetodb_xls_role')
    FOR XML PATH('')
    )

PRINT '';
PRINT 'Copying role members:';
PRINT @sql

EXEC (@sql)

GO
